History
=======
0.1.0 (2019-08-21)

* First commit. Github Link: https://github.com/linshuliang/tb-paddle

0.2.0 (2019-08-26)

* Append setup requirements, pillow.

0.3.1 (2019-08-27)

* Fix the bug of session_log.

0.3.2 (2019-09-04)

* Optimize the display effect of bbox.

* Append setup requirements - moviepy, which is necessary for API add\_video.

0.3.3 (2019-09-05)

* Fix the bug of Paddle Graph.

0.3.4 (2019-09-12)

* modify the logging config.

* add RecordReader and Event\_File\_loader.

0.3.5 (2019-09-12)

* add SummaryReader

0.3.6 (2019-09-19)

* modify the limitation of tag.

